@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------
-#     Copyright (C) 2012-2014  Serge Iovleff, University Lille 1, Inria
+#     Copyright (C) 2012-2015  Serge Iovleff, University Lille 1, Inria
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as
@@ -21,11 +21,13 @@
 #
 #    Contact : S..._Dot_I..._At_stkpp_Dot_org (see copyright for ...)
 #
+
 #-----------------------------------------------------------------------
-#' Build a vector of Gaussian model names.
+#' Create a vector of diagonal Gaussian mixture model names.
 #'
-#' In a diagonal Gaussian model, we assume that the variance
-#' matrices are diagonal in each cluster. This gives rise to 8 models:
+#' In a diagonal Gaussian mixture model, we assume that the variance
+#' matrices are diagonal in each cluster. Assumptions on the proportions
+#' and standard deviations give rise to 8 models:
 #' \enumerate{
 #'  \item {The proportions can be equal or free.}
 #'  \item {The standard deviations can be equal or free for all the variables.}
@@ -35,14 +37,14 @@
 #' The model names are summarized in the following array:
 #' \tabular{llll}{
 #'  Model Name      \tab Proportions \tab s.d. in variables \tab s.d. in clusters \cr
-#'  gaussian_p_sjk  \tab Equal \tab Free                  \tab Free  \cr
-#'  gaussian_p_sj   \tab Equal \tab Free                  \tab Equal \cr
-#'  gaussian_p_sk   \tab Equal \tab Equal                 \tab Free  \cr
-#'  gaussian_p_s    \tab Equal \tab Equal                \tab Equal \cr
-#'  gaussian_pk_sjk \tab Free  \tab Free                 \tab Free  \cr
-#'  gaussian_pk_sj  \tab Free  \tab Free                 \tab Equal \cr
-#'  gaussian_pk_sk  \tab Free  \tab Equal                \tab Free  \cr
-#'  gaussian_pk_s   \tab Free  \tab Equal                \tab Equal \cr
+#'  gaussian_p_sjk  \tab Equal       \tab Free              \tab Free  \cr
+#'  gaussian_p_sj   \tab Equal       \tab Free              \tab Equal \cr
+#'  gaussian_p_sk   \tab Equal       \tab Equal             \tab Free  \cr
+#'  gaussian_p_s    \tab Equal       \tab Equal             \tab Equal \cr
+#'  gaussian_pk_sjk \tab Free        \tab Free              \tab Free  \cr
+#'  gaussian_pk_sj  \tab Free        \tab Free              \tab Equal \cr
+#'  gaussian_pk_sk  \tab Free        \tab Equal             \tab Free  \cr
+#'  gaussian_pk_s   \tab Free        \tab Equal             \tab Equal \cr
 #' }
 #'
 #' @param prop A character string equal to "equal", "free" or "all". Default is "all".
@@ -70,26 +72,25 @@ clusterDiagGaussianNames <- function(prop = "all", sdInCluster="all", sdBetweenC
          , "gaussian_p_sjk", "gaussian_p_sj", "gaussian_p_sk", "gaussian_p_s")
   propFree  = c( "gaussian_pk_sjk", "gaussian_pk_sj", "gaussian_pk_sk", "gaussian_pk_s")
   propEqual = c( "gaussian_p_sjk", "gaussian_p_sj", "gaussian_p_sk", "gaussian_p_s")
-  varJFree  = c( "gaussian_pk_sjk", "gaussian_pk_sj", "gaussian_p_sjk", "gaussian_p_sj")
-  varJEqual = c( "gaussian_pk_sk", "gaussian_pk_s", "gaussian_p_sk", "gaussian_p_s")
-  varKFree  = c( "gaussian_pk_sjk", "gaussian_pk_sk", "gaussian_p_sjk", "gaussian_p_sk")
-  varKEqual = c( "gaussian_pk_sj", "gaussian_pk_s", "gaussian_p_sj", "gaussian_p_s")
+  sdJFree  = c( "gaussian_pk_sjk", "gaussian_pk_sj", "gaussian_p_sjk", "gaussian_p_sj")
+  sdJEqual = c( "gaussian_pk_sk", "gaussian_pk_s", "gaussian_p_sk", "gaussian_p_s")
+  sdKFree  = c( "gaussian_pk_sjk", "gaussian_pk_sk", "gaussian_p_sjk", "gaussian_p_sk")
+  sdKEqual = c( "gaussian_pk_sj", "gaussian_pk_s", "gaussian_p_sj", "gaussian_p_s")
 
   res = all;
   if (prop == "free")  { res = intersect(res, propFree);}
   if (prop == "equal") { res = intersect(res, propEqual);}
-  if (sdInCluster =="free")  { res = intersect(res, varJFree);}
-  if (sdInCluster == "equal") { res = intersect(res, varJEqual);}
-  if (sdBetweenCluster =="free")  { res = intersect(res, varKFree);}
-  if (sdBetweenCluster =="equal") { res = intersect(res, varKEqual);}
+  if (sdInCluster =="free")  { res = intersect(res, sdJFree);}
+  if (sdInCluster == "equal") { res = intersect(res, sdJEqual);}
+  if (sdBetweenCluster =="free")  { res = intersect(res, sdKFree);}
+  if (sdBetweenCluster =="equal") { res = intersect(res, sdKEqual);}
 
   res
 }
 
-#' check if a vector of diagonal Gaussian model name is correct.
+#' check if a vector of diagonal Gaussian mixture model name is correct.
 #' @param names a vector of character
 #' @rdname clusterDiagGaussianNames
-#' @keywords internal
 clusterValidDiagGaussianNames <- function(names)
 {
   nb = length(names)
@@ -102,9 +103,9 @@ clusterValidDiagGaussianNames <- function(names)
 }
 
 #-----------------------------------------------------------------------
-#' Build a vector of gamma model names.
+#' Create a vector of gamma mixture model names.
 #'
-#' In a gamma model, we can assume that the shapes are equal in each/all
+#' In a gamma mixture model, we can assume that the shapes are equal in each/all
 #' cluster(s) or not. We can also assume that the scales are equal in each/all
 #' cluster(s) or not.
 #'
@@ -124,16 +125,16 @@ clusterValidDiagGaussianNames <- function(names)
 #'
 #' The model names are summarized in the following array:
 #' \tabular{lllll}{
-#'          &  ajk                &  ak            &  aj            &  a \\
-#'bjk       & gamma_*_ajk_bjk     & gamma_*_ak_bjk & gamma_*_aj_bjk & gamma_*_a_bjk \\
-#'bk        & gamma_*_ajk_bk      & gamma_*_ak_bk  & gamma_*_aj_bk  & gamma_*_a_bk \\
-#'bj        & gamma_*_ajk_bj      & gamma_*_ak_bj  & NA             & NA  \\
-#'b         & gamma_*_ajk_b       & gamma_*_ak_b   & NA             & NA \\
+#'          &  ajk                &  ak            &  aj            &  a \cr
+#'bjk       & gamma_*_ajk_bjk     & gamma_*_ak_bjk & gamma_*_aj_bjk & gamma_*_a_bjk \cr
+#'bk        & gamma_*_ajk_bk      & gamma_*_ak_bk  & gamma_*_aj_bk  & gamma_*_a_bk \cr
+#'bj        & gamma_*_ajk_bj      & gamma_*_ak_bj  & NA             & NA  \cr
+#'b         & gamma_*_ajk_b       & gamma_*_ak_b   & NA             & NA \cr
 #'}
 #'
 #' @param prop A character string equal to "equal", "free" or "all". Default is "all".
 #' @param shapeInCluster A character string equal to "equal", "free" or "all". Default is "all".
-#' @param shapeBetweenCluster A character string equal to "equal", "free" or "all". Default is "free".
+#' @param shapeBetweenCluster A character string equal to "equal", "free" or "all". Default is "all".
 #' @param scaleInCluster A character string equal to "equal", "free" or "all". Default is "all".
 #' @param scaleBetweenCluster A character string equal to "equal", "free" or "all". Default is "all".
 #'
@@ -145,8 +146,8 @@ clusterValidDiagGaussianNames <- function(names)
 #'
 #' @rdname clusterGammaNames
 #' @export
-clusterGammaNames <- function(prop = "all", shapeInCluster="all", shapeBetweenCluster="free"
-                                   , scaleInCluster= "all", scaleBetweenCluster="all")
+clusterGammaNames <- function( prop = "all", shapeInCluster="all", shapeBetweenCluster="all"
+                             , scaleInCluster= "all", scaleBetweenCluster="all")
 {
   if(sum(prop %in% c("equal","free","all")) != 1)
   { stop("prop is not valid. See ?clusterGammaNames for the list of prop.")}
@@ -246,32 +247,24 @@ clusterGammaNames <- function(prop = "all", shapeInCluster="all", shapeBetweenCl
   res
 }
 
-#' check if a vector of gamma model name is correct.
+#' check if a vector of gamma mixture model name is correct.
 #' @param names a vector of character
 #' @rdname clusterGammaNames
-#' @keywords internal
 clusterValidGammaNames <- function(names)
 {
   nb = length(names)
   if ( nb == 0 ) { return(FALSE);}
 
-  all = c( "gamma_p_ajk_bjk", "gamma_p_ajk_bk", "gamma_p_ajk_bj", "gamma_p_ajk_b"
-         , "gamma_p_ak_bjk",  "gamma_p_ak_bk",  "gamma_p_ak_bj",  "gamma_p_ak_b"
-         , "gamma_p_aj_bjk",  "gamma_p_aj_bk"
-         , "gamma_p_a_bjk",   "gamma_p_a_bk"
-         , "gamma_pk_ajk_bjk", "gamma_pk_ajk_bk", "gamma_pk_ajk_bj", "gamma_pk_ajk_b"
-         , "gamma_pk_ak_bjk",  "gamma_pk_ak_bk",  "gamma_pk_ak_bj",  "gamma_pk_ak_b"
-         , "gamma_pk_aj_bjk",  "gamma_pk_aj_bk"
-         , "gamma_pk_a_bjk",   "gamma_pk_a_bk"
-         )
+  all = clusterGammaNames();
   for (i in 1:nb)
   {  if ( sum(names[i] %in% all) != 1 ) { return(FALSE);}}
   return(TRUE)
 }
 
-#' Build a vector of Categorical model names.
+#-----------------------------------------------------------------------
+#' Create a vector of Categorical mixture model names.
 #'
-#' In a Categorical model, we can build 4 models:
+#' In a Categorical mixture model, we can build 4 models:
 #' \enumerate{
 #'  \item {The proportions can be equal or free.}
 #'  \item {The probabilities can be equal or free for all the variables.}
@@ -318,10 +311,10 @@ clusterCategoricalNames <- function(prop = "all", probabilities="all")
   res
 }
 
-#' check if a vector of Categorical model name is correct.
+
+#' check if a vector of Categorical mixture model name is correct.
 #' @param names a vector of character
 #' @rdname clusterCategoricalNames
-#' @keywords internal
 clusterValidCategoricalNames <- function(names)
 {
   nb = length(names)
@@ -333,9 +326,9 @@ clusterValidCategoricalNames <- function(names)
   return(TRUE)
 }
 
-#' Build a vector of Poisson model names.
+#' Create a vector of Poisson mixture model names.
 #'
-#' In a poisson model, we can build 4 models:
+#' In a Poisson mixture model, we can build 4 models:
 #' \enumerate{
 #'  \item {The proportions can be equal or free.}
 #'  \item {The means can be equal, free or proportional for all the variables.}
@@ -375,21 +368,20 @@ clusterPoissonNames <- function(prop = "all", mean="all")
   meanFree  = c( "poisson_pk_ljk", "poisson_p_ljk")
   meanEqual = c( "poisson_pk_lk", "poisson_p_lk")
   meanProp  = c( "poisson_pk_ljlk", "poisson_p_ljlk")
-  
+
   res = all;
   if (prop == "free")  { res = intersect(res, propFree);}
   if (prop == "equal") { res = intersect(res, propEqual);}
   if (mean =="Free")  { res = intersect(res, meanFree);}
   if (mean =="equal") { res = intersect(res, meanEqual);}
   if (mean =="proportional") { res = intersect(res, meanProp);}
-  
+
   res
 }
 
-#' check if a vector of Poisson model name is correct.
+#' check if a vector of Poisson mixture model name is correct.
 #' @param names a vector of character
 #' @rdname clusterPoissonNames
-#' @keywords internal
 clusterValidPoissonNames <- function(names)
 {
   nb = length(names)
@@ -401,3 +393,67 @@ clusterValidPoissonNames <- function(names)
   return(TRUE)
 }
 
+#' Create a vector of Kernel mixture model names.
+#'
+#' In a diagonal Kernel mixture model, we can assume that
+#' \enumerate{
+#'  \item {The proportions can be equal or free.}
+#'  \item {The standard deviations can be equal or free for all the clusters.}
+#' }
+#' This give rise to four models.
+#'
+#' The model names are summarized in the following array:
+#' \tabular{lll}{
+#'  Model Name           \tab Proportions \tab s.d. between clusters \cr
+#'  kernelGaussian_p_sk  \tab Equal       \tab Free                  \cr
+#'  kernelGaussian_p_s   \tab Equal       \tab Equal                 \cr
+#'  kernelGaussian_pk_sk \tab Free        \tab Free                  \cr
+#'  kernelGaussian_pk_s  \tab Free        \tab Equal                 \cr
+#' }
+#'
+#' @param prop A character string equal to "equal", "free" or "all". Default is "all".
+#' @param sdBetweenCluster A character string equal to "equal", "free" or "all". Default is "all".
+#'
+#' @return A vector of character with the model names.
+#' @examples
+#' clusterKernelNames()
+#' ## same as c("kernelGaussian_p_sk", "kernelGaussian_pk_sk")
+#' clusterKernelNames(prop="all", sdBetweenCluster= "free")
+#'
+#' @rdname clusterKernelNames
+#' @export
+clusterKernelNames <- function(prop = "all", sdBetweenCluster = "all")
+{
+  if(sum(prop %in% c("equal","free","all")) != 1)
+  { stop("prop is not valid. See ?clusterKernelNames for the list of prop.")}
+  if(sum(sdBetweenCluster %in% c("equal","free","all")) != 1)
+  { stop("sdBetweenCluster is not valid. See ?clusterKernelNames for the list of sdBetweenCluster.")}
+
+  all = c( "kernelGaussian_pk_sk", "kernelGaussian_pk_s", "kernelGaussian_p_sk", "kernelGaussian_p_s")
+  propFree  = c( "kernelGaussian_pk_sk", "kernelGaussian_pk_s")
+  propEqual = c( "kernelGaussian_p_sk", "kernelGaussian_p_s")
+  sdKFree   = c( "kernelGaussian_pk_sk", "kernelGaussian_p_sk")
+  sdKEqual  = c( "kernelGaussian_pk_s", "kernelGaussian_p_s")
+
+  res = all;
+  if (prop == "free")  { res = intersect(res, propFree);}
+  if (prop == "equal") { res = intersect(res, propEqual);}
+  if (sdBetweenCluster =="free")  { res = intersect(res, sdKFree);}
+  if (sdBetweenCluster =="equal") { res = intersect(res, sdKEqual);}
+
+  res
+}
+
+#' check if a vector of kernel mixture model name is correct.
+#' @param names a vector of character
+#' @rdname clusterKernelNames
+clusterValidKernelNames <- function(names)
+{
+  nb = length(names)
+  if ( nb == 0 ) { return(FALSE);}
+
+  all = clusterKernelNames();
+  for (i in 1:nb)
+  {  if ( sum(names[i] %in% all) != 1 ) { return(FALSE);}}
+  return(TRUE)
+}
